@@ -436,7 +436,7 @@ class VariableClAutopartitionCalculateFormat(VariableClAutopartitionDefaultForma
     """
     Формат файловой системы для calculate
     """
-    opt = ["--calculate-fs"]
+    opt = ["--data-fs"]
     metavalue = "FS"
 
     def init(self):
